@@ -22,6 +22,14 @@ test!(
     r#"import test from "./test.json";"#
 );
 
+test!(
+    syntax(),
+    |_| tr(),
+    side_effect_import_with_assertions,
+    r#"import "./test.json" assert {type: "json"};"#,
+    r#"import "./test.json";"#
+);
+
 test!(
     syntax(),
     |_| tr(),
